NumLPA package documentation
============================

.. toctree::
   :maxdepth: 2
   :caption: Contents:
   :glob:

   usage
   auto/numlpa

Indices and tables
==================

* :ref:`genindex`
* :ref:`modindex`
* :ref:`search`
